<?php

namespace Drupal\browser_back_button\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a block with Browser Back Button.
 *
 * @Block(
 *   id = "browser_back_button_block",
 *   admin_label = @Translation("Browser Back Button Block"),
 *   category = @Translation("Browser Back Button Block"),
 * )
 */
class BrowserBackButtonBlock extends BlockBase {  
  
  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'body' => [
        'value' => $this->t('Back'),
      ],
      'reload_status' => 1,
      
    ];
  }
  
  /**
   * {@inheritdoc}
   */
  public function build() {    
    $data = [];    
    $data['body'] = check_markup($this->configuration['body']['value'], $this->configuration['body']['format']);    
    $data['reload_status'] = $this->configuration['reload_status'];
    return [      
      '#theme' => 'browser_back_button_history',
      '#data' => $data,
      '#attached' => [
        'library' => [
          'browser_back_button/browser_back_button.history',
        ],
        'drupalSettings' => [
          'browser_back_button' => [
            'data' => $data,
          ]
        ]
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $form['body'] = [
      '#type' => 'text_format',
      '#title' => $this->t('Back Button Text or Image'),
      '#default_value' => $this->configuration['body']['value'],
      '#format' => !isset($this->configuration['body']['format']) ? filter_default_format() : $this->configuration['body']['format']
    ];  
       
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    $this->setConfigurationValue('body', $form_state->getValue('body'));
  }  

}